/**
 * RokNewsPager Module
 *
 * @package		Joomla
 * @subpackage	RokNewsPager Module
 * @copyright Copyright (C) 2009 RocketTheme. All rights reserved.
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL, see RT-LICENSE.php
 * @author RocketTheme, LLC
 *
 */

var RokNewsPagerStorage = [];
var RokNewsPager = new Class({
    version: 1.5,
    Implements: [Options, Events],
    options: {
        autoupdate: true,
        delay: 3000,
        accordion: false
    },
    initialize: function (f) {
        var g = this;
        this.setOptions(f);
        this.storage = RokNewsPagerStorage;
        this.elements = $$('.roknewspager');
        this.modules = this.elements.getParent('.roknewspager-wrapper')
            .getParent();
        this.spinners = [];
        this.arrows = {
            'prev': [],
            'next': []
        };
        this.pages = [];
        this.current = [];
        this.overlay = [];
        this.effects = [];
        this.ajax = [];
        this.timer = [];
        this.accordions = [];
        this.elements.each(function (c, i) {
            var d = c.getParent('.roknewspager-wrapper')
                .getParent()
                .getElement('.roknewspager-pages');
            this.pages.push(d);
            this.arrows.prev.push(!d ? null : d.getElement('.roknewspager-prev'));
            this.arrows.next.push(!d ? null : d.getElement('.roknewspager-next'));
            this.spinners.push(!d ? null : d.getElement('.roknewspager-spinner'));
            this.ajax.push(new Request({
                url: this.storage[i]['url'],
                method: 'get'
            }));
            this.overlay.push(new Element('div', {
                'class': 'roknewspager-overlay'
            })
                .setStyles({
                'opacity': 0,
                'display': 'none',
                'position': 'absolute',
                'top': 0,
                'left': 0
            })
                .inject(c, 'before'));
            c.getParent()
                .setStyle('overflow', 'hidden');
            this.effects.push(new Fx.Tween(this.overlay[i], {
                'duration': 200
            })
                .set('opacity', 1));
            this.current.push(0);
            this.accordions.push(false);
            this.events(i);
            this.ajax[i].addEvent('onComplete', function (a) {
                this.complete(a, i)
            }.bind(this));
            if (RokNewsPagerStorage[i].autoupdate) {
                this.ajax[i].addEvent('onRequest', function () {
                    $clear(this.timer[i])
                }.bind(this));
                this.modules[i].addEvents({
                    'mouseenter': function () {
                        $clear(this.timer[i])
                    }.bind(this),
                    'mousemove': function () {
                        $clear(this.timer[i])
                    }.bind(this),
                    'mouseleave': function () {
                        $clear(this.timer[i]);
                        this.timer[i] = this.next.periodical(RokNewsPagerStorage[i].delay, this, i)
                    }.bind(this)
                });
                this.timer[i] = this.next.periodical(RokNewsPagerStorage[i].delay, this, i)
            }
            var e = c.getElements('.roknewspager-h3')
                .getParent();
            if (RokNewsPagerStorage[i].accordion) {
                this.accordions[i] = new Accordion(c.getElements('.roknewspager-toggle'), c.getElements('.roknewspager-div'), {
                    opacity: false,
                    onActive: function (a) {
                        if (this.togglers.length) {
                            $$(this.togglers)
                                .removeClass('roknewspager-toggle-active');
                            c.getChildren()
                                .removeClass('active')
                        }
                        a.addClass('roknewspager-toggle-active');
                        var b = this.togglers.indexOf(a);
                        c.getChildren()[b].addClass('active')
                    }
                }, c)
            }
        }, this)
    },
    complete: function (a, b) {
        if (RokNewsPagerStorage[b].autoupdate) {
            $clear(this.timer[b]);
            this.timer[b] = this.next.periodical(RokNewsPagerStorage[b].delay, this, b)
        }
        this.overlay[b].setStyles({
            'width': this.elements[b].getSize()
                .x + this.elements[b].getParent()
                .getStyle('padding-left')
                .toInt() + this.elements[b].getParent()
                .getStyle('padding-right')
                .toInt(),
            'height': (Browser.Engine.trident4) ? this.elements[b].getSize()
                .x : 3000
        });
        var c = new Element('div')
            .set('html', a);
        if (!RokNewsPagerStorage[b].accordion) c.getElements('.roknewspager > li')
            .inject(this.elements[b].empty());
        else c.getElement('.roknewspager')
            .getChildren()
            .inject(this.elements[b].empty());
        this.hideSpinner(b);
        this.effects[b].start('opacity', 0)
    },
    events: function (c) {
        if (!this.pages[c]) return;
        var d = this.pages[c].getElements('li');
        d.each(function (b, i) {
            b.addEvent('click', function () {
                if (b.hasClass('active')) return;
                if (!i) {
                    this.arrows.prev[c].addClass('roknewspager-prev-disabled')
                        .removeClass('roknewspager-prev');
                    this.arrows.next[c].addClass('roknewspager-next')
                        .removeClass('roknewspager-next-disabled')
                } else if (i == d.length - 1) {
                    this.arrows.next[c].addClass('roknewspager-next-disabled')
                        .removeClass('roknewspager-next');
                    this.arrows.prev[c].addClass('roknewspager-prev')
                        .removeClass('roknewspager-prev-disabled')
                } else {
                    this.arrows.prev[c].addClass('roknewspager-prev')
                        .removeClass('roknewspager-prev-disabled');
                    this.arrows.next[c].addClass('roknewspager-next')
                        .removeClass('roknewspager-next-disabled')
                }
                this.showSpinner(c);
                this.pages[c].getElements('li')
                    .removeClass('active');
                b.addClass('active');
                this.current[c] = i;
                this.overlay[c].setStyles({
                    'opacity': 0.9,
                    'display': 'block'
                });
                var a = this.elements[c].getProperty('perpage') * i;
                this.ajax[c].options.url = this.storage[c]['url'].replace("_OFFSET_", a);
                this.ajax[c].get()
            }.bind(this))
        }, this);
        this.arrows.prev[c].addClass('roknewspager-prev-disabled')
            .removeClass('roknewspager-prev');
        this.arrows.prev[c].addEvent('click', function () {
            var a = this.current[c];
            if (RokNewsPagerStorage[c].autoupdate) {
                $clear(this.timer[c])
            }
            this.arrows.next[c].addClass('roknewspager-next')
                .removeClass('roknewspager-next-disabled');
            if (!a || a - 1 == 0) {
                this.arrows.prev[c].addClass('roknewspager-prev-disabled')
                    .removeClass('roknewspager-prev')
            }
            if (d[a - 1]) d[a - 1].fireEvent('click')
        }.bind(this));
        this.arrows.next[c].addEvent('click', function () {
            var a = this.current[c];
            if (RokNewsPagerStorage[c].autoupdate) {
                $clear(this.timer[c])
            }
            this.arrows.prev[c].addClass('roknewspager-prev')
                .removeClass('roknewspager-prev-disabled');
            if (a == d.length - 1 || a + 1 == d.length - 1) {
                this.arrows.next[c].addClass('roknewspager-next-disabled')
                    .removeClass('roknewspager-next')
            }
            if (d[a + 1]) d[a + 1].fireEvent('click')
        }.bind(this))
    },
    showSpinner: function (a) {
        return this.spinners[a].setStyle('display', 'block')
    },
    hideSpinner: function (a) {
        if (RokNewsPagerStorage[a].accordion) this.accordionInit(a);
        return this.spinners[a].setStyle('display', 'none')
    },
    add: function (a) {
        return this.storage.push($merge(this.options, a))
    },
    next: function (a) {
        if (this.current[a] == this.pages[a].getElements('li')
            .length - 1) this.current[a] = -1;
        this.arrows.next[a].fireEvent('click')
    },
    accordionInit: function (c) {
        this.accordions[c].elements = [];
        this.accordions[c].togglers = [];
        this.accordions[c].previous = -1;
        this.elements[c].getElements('.roknewspager-h3')
            .getParent()
            .each(function (a, i) {
            var b = a.getFirst(),
                toggle = a.getFirst()
                    .getElement('.roknewspager-toggle'),
                pane = a.getLast();
            this.accordions[c].addSection(toggle, pane);
            b.inject(a);
            toggle.inject(b);
            pane.inject(a)
        }, this);
        this.accordions[c].display(0)
    }
});
window.addEvent('domready', function () {
    new RokNewsPager()
});